# =====================================
# generator=datazen
# version=3.1.2
# hash=7d9db5b03071a6b0e78c3e545b31a7ea
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A configuration-file management system."
PKG_NAME = "rcmpy"
VERSION = "1.2.0"
